summaryrefslogtreecommitdiffstats
path: root/chrome/browser/history/thumbnail_database.cc
diff options
context:
space:
mode:
authorestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-03-18 20:50:46 +0000
committerestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-03-18 20:50:46 +0000
commit0a8f88c90840e5f642e6bc64e150229d336eca72 (patch)
tree646c7fd7c7ccd20c8902c9b8058b5f675418c098 /chrome/browser/history/thumbnail_database.cc
parent420949ff13d309c7bbc56173bca33ee4ffafd1b3 (diff)
downloadchromium_src-0a8f88c90840e5f642e6bc64e150229d336eca72.zip
chromium_src-0a8f88c90840e5f642e6bc64e150229d336eca72.tar.gz
chromium_src-0a8f88c90840e5f642e6bc64e150229d336eca72.tar.bz2
Ports all of the chrome/browser/history code to use FilePath, except
for DownloadDatabase, InMemoryDatabase, and RedirectUiTest. Except for in those files, we now only use std::wstring for text strings. This CL also enables two more unittests on Mac. patch by Rohit Rao. http://codereview.chromium.org/48018 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@12009 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/history/thumbnail_database.cc')
-rw-r--r--chrome/browser/history/thumbnail_database.cc8
1 files changed, 4 insertions, 4 deletions
diff --git a/chrome/browser/history/thumbnail_database.cc b/chrome/browser/history/thumbnail_database.cc
index dd59019..fcd5332 100644
--- a/chrome/browser/history/thumbnail_database.cc
+++ b/chrome/browser/history/thumbnail_database.cc
@@ -33,13 +33,13 @@ ThumbnailDatabase::~ThumbnailDatabase() {
// The DBCloseScoper will delete the DB and the cache.
}
-InitStatus ThumbnailDatabase::Init(const std::wstring& db_name,
+InitStatus ThumbnailDatabase::Init(const FilePath& db_name,
const HistoryPublisher* history_publisher) {
history_publisher_ = history_publisher;
- // Open the thumbnail database, using the narrow version of open so that
- // the DB is in UTF-8.
- if (sqlite3_open(WideToUTF8(db_name).c_str(), &db_) != SQLITE_OK)
+ // OpenSqliteDb uses the narrow version of open, so the resulting DB is in
+ // UTF-8.
+ if (OpenSqliteDb(db_name, &db_) != SQLITE_OK)
return INIT_FAILURE;
// Set the database page size to something larger to give us